@@ -38,7 +38,7 @@ main(int argc, char **argv)
     NXARG(bq, "Whether to print list backwards");
     // Note: with benchmark: whether to go backwards
 
-#ifdef TIMING
+#if defined TIMING
 
     if ( !bq )
     {
