@@ -27,13 +27,13 @@ main(int argc, char **argv)
     NXARG(q, "0 ==> show all, 1 ==> only necklaces, 2 ==> only Lyndon words");
 
     lyndon_words L(n, a, z);
-#ifdef TIMING
+#if defined TIMING
 #else
     const ulong * x = L.data_1();  // one-based
 #endif
 
     ulong ct = 0;
-#ifdef TIMING
+#if defined TIMING
     do { ++ct; } while ( 0 != L.next() );
 
 #else  // TIMING
