@@ -117,7 +117,7 @@ main(int argc, char **argv)
 //    ulong i = L.first( cond_noteq );
 //    ulong i = L.first( cond_true );
 
-#ifdef TIMING
+#if defined TIMING
     while ( i )
     {
         ++ct;
