@@ -30,7 +30,7 @@ main(int argc, char **argv)
     ulong rr = 3;
     NXARG(rr, "Base (radix) of digits (0==>falling factorial, 1==>rising factorial)");
 
-#ifdef TIMING
+#if defined TIMING
     bool bq = 0;
     NXARG(bq, "Benchmark: whether to generate in backward order");
     mixedradix_naf M(n, rr);
@@ -48,7 +48,7 @@ main(int argc, char **argv)
 #endif
 
     ulong ct = 0;
-#ifdef TIMING
+#if defined TIMING
     if ( ! bq )
     {
         cout << "forward:" << endl;
