@@ -33,7 +33,7 @@ main(int argc, char **argv)
         if ( ni != mi )  continue;
 
         ++ct;
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
         P.print("    ");
         cout << setw(4) << mi;
