@@ -37,7 +37,7 @@ main(int argc, char **argv)
             }
         }
         mct += c;
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
         M.print("  ", false);
         cout << setw(4) << c;
